"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRangesForDiff = exports.getDiffForFile = void 0;
const child_process = __importStar(require("child_process"));
const path = __importStar(require("path"));
const Range_1 = require("./Range");
const sanitizeFilePath = (filePath) => JSON.stringify(path.resolve(filePath));
const getDiffForFile = (filePath, staged = false) => child_process
    .execSync(`git diff --diff-filter=ACM --unified=0 HEAD ${staged ? " --staged" : ""} -- ${sanitizeFilePath(filePath)}`)
    .toString();
exports.getDiffForFile = getDiffForFile;
const isHunkHeader = (input) => {
    const hunkHeaderRE = new RegExp(/^@@ .* @@/g);
    return input.match(hunkHeaderRE);
};
const getRangeForChangedLines = (line) => {
    var _a, _b, _c, _d;
    const rangeRE = new RegExp(/^@@ .* \+(?<start>\d+)(?<linesCountDelimiter>,(?<linesCount>\d+))? @@/);
    const range = rangeRE.exec(line);
    if (range === null) {
        throw Error(`Couldn't match regex with line '${line}'`);
    }
    if (((_a = range.groups) === null || _a === void 0 ? void 0 : _a.start) === undefined) {
        /*
         * NOTE: Never happens, because RegExp requires start to be a
         * required number
         */
        throw Error("Couldn't match regex to find start");
    }
    const linesCount = ((_b = range.groups) === null || _b === void 0 ? void 0 : _b.linesCountDelimiter) && ((_c = range.groups) === null || _c === void 0 ? void 0 : _c.linesCount)
        ? parseInt(range.groups.linesCount)
        : 1;
    const hasAddedLines = linesCount !== 0;
    const start = parseInt((_d = range.groups) === null || _d === void 0 ? void 0 : _d.start);
    const end = start + linesCount;
    return hasAddedLines ? new Range_1.Range(start, end) : null;
};
const removeNullRanges = (r) => r !== null;
const getRangesForDiff = (diff) => {
    return diff
        .split("\n")
        .filter(isHunkHeader)
        .map(getRangeForChangedLines)
        .filter(removeNullRanges);
};
exports.getRangesForDiff = getRangesForDiff;
//# sourceMappingURL=git.js.map